<!DOCTYPE TS><TS>
<context>
    <name>ArtefactAction</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>AskCost</name>
    <message>
        <source>Change</source>
        <translation>Changer</translation>
    </message>
</context>
<context>
    <name>AskDiversificationList</name>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>BuildingAction</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>DecorationEffect</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>DialogArtefactAction</name>
    <message>
        <source>Action type: </source>
        <translation>Type d&apos;action:</translation>
    </message>
    <message>
        <source>Characteristic</source>
        <translation>Caractéristique</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation>Sort</translation>
    </message>
    <message>
        <source>Fixed value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <source>Ratio</source>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>Modification type: </source>
        <translation>Type de modif:</translation>
    </message>
    <message>
        <source>Parameter: </source>
        <translation>Paramètre:</translation>
    </message>
    <message>
        <source>Value: </source>
        <translation>Valeur:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DialogBuildingAction</name>
    <message>
        <source>Action type: </source>
        <translation>Type d&apos;action:</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>First Time</source>
        <translation>Première fois</translation>
    </message>
    <message>
        <source>First Time Lord</source>
        <translation>Première fois pour ce seigneur</translation>
    </message>
    <message>
        <source>Next Time</source>
        <translation>Autres fois</translation>
    </message>
    <message>
        <source>Attack</source>
        <translation>Attaque</translation>
    </message>
    <message>
        <source>Defense</source>
        <translation>Défense</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Puissance</translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation>Savoir</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Déplacement</translation>
    </message>
    <message>
        <source>Maxmove</source>
        <translation>Déplacement max</translation>
    </message>
    <message>
        <source>TechPoint</source>
        <translation>Technicité</translation>
    </message>
    <message>
        <source>MaxTechPoint</source>
        <translation>Technicité max</translation>
    </message>
    <message>
        <source>Morale</source>
        <translation>Moral</translation>
    </message>
    <message>
        <source>Luck</source>
        <translation>Chance</translation>
    </message>
    <message>
        <source>Vision</source>
        <translation>Vision</translation>
    </message>
    <message>
        <source>Experience</source>
        <translation>Expérience</translation>
    </message>
    <message>
        <source>Skill</source>
        <translation>Compétence</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefact</translation>
    </message>
    <message>
        <source>Unit</source>
        <translation>Unité</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Ressource</translation>
    </message>
    <message>
        <source>Random Resource</source>
        <translation>Ressource aléatoire</translation>
    </message>
    <message>
        <source>Elementary Action: </source>
        <translation>Action élémentaire :</translation>
    </message>
    <message>
        <source>Param: </source>
        <translation>Paramètre :</translation>
    </message>
    <message>
        <source>Coeff: </source>
        <translation>Coeff :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DialogEffect</name>
    <message>
        <source>Effect type: </source>
        <translation>Type d&apos;effet :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Effect value: </source>
        <translation>Effet:</translation>
    </message>
</context>
<context>
    <name>EditCost</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>EditCreature</name>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Attack: </source>
        <translation>Attaque :</translation>
    </message>
    <message>
        <source>Defense: </source>
        <translation>Défense :</translation>
    </message>
    <message>
        <source>Max Health: </source>
        <translation>Santé max. :</translation>
    </message>
    <message>
        <source>Max Move: </source>
        <translation>Mouvements max. :</translation>
    </message>
    <message>
        <source>Dist Attack: </source>
        <translation>Attaque distante :</translation>
    </message>
    <message>
        <source>Min Damages: </source>
        <translation>Dommages minimaux :</translation>
    </message>
    <message>
        <source>Max Damages: </source>
        <translation>Dommages maximaux :</translation>
    </message>
    <message>
        <source>Morale: </source>
        <translation>Moral :</translation>
    </message>
    <message>
        <source>Luck: </source>
        <translation>Chance :</translation>
    </message>
    <message>
        <source>Size: </source>
        <translation>Taille :</translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation>Coût :</translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation>Coût de maintenance :</translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation>Image :</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Race:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Nombre:</translation>
    </message>
</context>
<context>
    <name>MapDispositionEditor</name>
    <message>
        <source>Free</source>
        <translation>Libre</translation>
    </message>
    <message>
        <source>Occupied</source>
        <translation>Occupé</translation>
    </message>
    <message>
        <source>Door</source>
        <translation>Porte</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Colonnes : </translation>
    </message>
    <message>
        <source>Rows:</source>
        <translation>Lignes : </translation>
    </message>
</context>
<context>
    <name>PreviewBaseDialog</name>
    <message>
        <source>Buildings</source>
        <translation>Bâtiments</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Effect &apos;</source>
        <translation>Effet &apos;</translation>
    </message>
    <message>
        <source>&apos; with param </source>
        <translation>&apos; avec comme paramètre </translation>
    </message>
    <message>
        <source>Action: </source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Charac </source>
        <translation>Carac</translation>
    </message>
    <message>
        <source>Spell </source>
        <translation>Sort</translation>
    </message>
    <message>
        <source> modify by </source>
        <translation>modifié par</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source> elementary </source>
        <translation>élémentaire</translation>
    </message>
</context>
<context>
    <name>SectionArtefact</name>
    <message>
        <source>Artefact</source>
        <translation>Artefact</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation>Position :</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icone :</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Objet :</translation>
    </message>
</context>
<context>
    <name>SectionBase</name>
    <message>
        <source> Base </source>
        <translation>Base</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Population: </source>
        <translation>Population :</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Prévisualisation</translation>
    </message>
    <message>
        <source> Base : %d/%d</source>
        <translation>Base : %d/%d</translation>
    </message>
    <message>
        <source>Res Cost: </source>
        <translation>Coût ress :</translation>
    </message>
    <message>
        <source>Growth: </source>
        <translation>Croissance : </translation>
    </message>
    <message>
        <source>Loss: </source>
        <translation>Perte : </translation>
    </message>
    <message>
        <source>Preview inside</source>
        <translation>Prévisualisation intérieur</translation>
    </message>
</context>
<context>
    <name>SectionBuilding</name>
    <message>
        <source>Building</source>
        <translation>Bâtiment</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation>Image :</translation>
    </message>
    <message>
        <source>Number Frames: </source>
        <translation>Nombre d&apos;animations :</translation>
    </message>
    <message>
        <source>Animation Freq.: </source>
        <translation>Fréq. d&apos;animation :</translation>
    </message>
</context>
<context>
    <name>SectionCreature</name>
    <message>
        <source>Race</source>
        <translation>Race</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source> Creature </source>
        <translation>Créature</translation>
    </message>
    <message>
        <source> Race : %d/%d</source>
        <translation>Race : %d/%d</translation>
    </message>
    <message>
        <source> Creature : %d/%d</source>
        <translation>Créature : %d/%d</translation>
    </message>
    <message>
        <source> Creature : %d/??</source>
        <translation>Créature : %d/??</translation>
    </message>
</context>
<context>
    <name>SectionDecoration</name>
    <message>
        <source>Decoration</source>
        <translation>Décoration</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Info: </source>
        <translation>Info :</translation>
    </message>
    <message>
        <source>Image: </source>
        <translation>Image :</translation>
    </message>
</context>
<context>
    <name>SectionExperience</name>
    <message>
        <source>List of required experience to gain for accessing the next level:</source>
        <translation>Liste des points d&apos;expériences pour changer de niveau :</translation>
    </message>
</context>
<context>
    <name>SectionGeneral</name>
    <message>
        <source>Fog of war</source>
        <translation type="obsolete">Champ de vision</translation>
    </message>
    <message>
        <source>Number of unit/lord</source>
        <translation>Nombre d&apos;unités par seigneur</translation>
    </message>
    <message>
        <source>Logo (200x180): </source>
        <translation>Logo (200x180) :</translation>
    </message>
    <message>
        <source>Vision management: </source>
        <translation>Gestion de la vision : </translation>
    </message>
</context>
<context>
    <name>SectionGround</name>
    <message>
        <source>Tiles</source>
        <translation>Sols</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Coef: </source>
        <translation>Coef :</translation>
    </message>
    <message>
        <source>Color: </source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <source>Team</source>
        <translation type="obsolete">Equipe</translation>
    </message>
    <message>
        <source>Tile </source>
        <translation>Sol</translation>
    </message>
</context>
<context>
    <name>SectionInsideBuilding</name>
    <message>
        <source> Building </source>
        <translation>Bâtiment</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation>Coût :</translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation>Coût de maintenance :</translation>
    </message>
    <message>
        <source> Building : %d/%d</source>
        <translation>Bâtiment : %d/%d</translation>
    </message>
    <message>
        <source>Action: </source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Params: </source>
        <translation>Paramètres :</translation>
    </message>
</context>
<context>
    <name>SectionLord</name>
    <message>
        <source>Lord</source>
        <translation>Seigneur</translation>
    </message>
    <message>
        <source>Photo: </source>
        <translation>Photo :</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icone :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Category : </source>
        <translation>Catégorie :</translation>
    </message>
    <message>
        <source>Race : </source>
        <translation type="obsolete">Race :</translation>
    </message>
    <message>
        <source>Attack : </source>
        <translation>Attaque :</translation>
    </message>
    <message>
        <source>Defense : </source>
        <translation>Défense :</translation>
    </message>
    <message>
        <source>Power : </source>
        <translation>Puissance :</translation>
    </message>
    <message>
        <source>Knowledge : </source>
        <translation>Savoir :</translation>
    </message>
    <message>
        <source>MaxMoves : </source>
        <translation>Mouvements max : </translation>
    </message>
    <message>
        <source>Vision : </source>
        <translation>Vision :</translation>
    </message>
    <message>
        <source> (Race: </source>
        <translation>(Race :</translation>
    </message>
</context>
<context>
    <name>SectionLordCategory</name>
    <message>
        <source>Lord Categories</source>
        <translation>Catégories des seigneurs</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Race: </source>
        <translation>Race :</translation>
    </message>
    <message>
        <source>Evolution of Attack skill (weight): </source>
        <translation>Evolution de l&apos;attaque (pondération) :</translation>
    </message>
    <message>
        <source>Evolution of Defense skill (weight): </source>
        <translation>Evolution de la défense (pondération) :</translation>
    </message>
    <message>
        <source>Evolution of Power skill (weight): </source>
        <translation>Evolution de la puissance (pondération) :</translation>
    </message>
    <message>
        <source>Evolution of Knowledge skill (weight): </source>
        <translation>Evolution du savoir (pondération) :</translation>
    </message>
</context>
<context>
    <name>SectionMachine</name>
    <message>
        <source>War Machine</source>
        <translation>Machines de guerre</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Param (1): </source>
        <translation>Param (1) :</translation>
    </message>
    <message>
        <source>Params: </source>
        <translation>Paramètres :</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icone :</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Objet :</translation>
    </message>
</context>
<context>
    <name>SectionRessource</name>
    <message>
        <source>Ressource</source>
        <translation>Ressource</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icone :</translation>
    </message>
    <message>
        <source>Small icon: </source>
        <translation>Petite icone :</translation>
    </message>
</context>
<context>
    <name>SectionSelector</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefacts</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipes</translation>
    </message>
    <message>
        <source>Bases</source>
        <translation>Bases</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Bâtiments</translation>
    </message>
    <message>
        <source>Creatures</source>
        <translation>Créatures</translation>
    </message>
    <message>
        <source>Decorations</source>
        <translation>Décorations</translation>
    </message>
    <message>
        <source>Grounds</source>
        <translation>Sols</translation>
    </message>
    <message>
        <source>Lords</source>
        <translation>Seigneurs</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressources</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Machines</translation>
    </message>
    <message>
        <source>Lord Categories</source>
        <translation>Catégories des seigneurs</translation>
    </message>
    <message>
        <source>Levels</source>
        <translation>Niveaux</translation>
    </message>
</context>
<context>
    <name>SectionTeam</name>
    <message>
        <source>Team</source>
        <translation>Equipe</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <source>Flag: </source>
        <translation>Drapeau :</translation>
    </message>
</context>
<context>
    <name>SelectionWidget</name>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>ThemeInterface</name>
    <message>
        <source>Theme editor for &apos;Attal - Lords of Doom&apos;</source>
        <translation>Editeur de thème pour &apos;Attal - Lords of Doom&apos;</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <source>New theme</source>
        <translation>Nouveau thème</translation>
    </message>
    <message>
        <source>Open theme</source>
        <translation>Ouvrir un thème</translation>
    </message>
    <message>
        <source>Save theme</source>
        <translation>Sauve le thème</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;New theme</source>
        <translation>&amp;Nouveau thème</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>&amp;Open theme</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>&amp;Save theme</source>
        <translation>&amp;Sauver</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Impossible de charger le thème</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Thème</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>n&apos;a pas été chargé correctement</translation>
    </message>
</context>
</TS>
